#include "mainwindow.h"
#include <iostream>

#include "contactmodifyer.h"

/* BRL
 *  Constructs a MainWindow which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 */
MainWindow::MainWindow( QWidget* parent,  const char* name, WFlags fl )
    : CMainWindowBase( parent, name, fl )
{
}

/*  
 *  Destroys the object and frees any allocated resources
 */
MainWindow::~MainWindow()
{
    // no need to delete child widgets, Qt does it all for us
}

/* 
 * public slot
 */
void MainWindow::slotSave()
{
	if (filename.isNull())
	{
		filename = QFileDialog::getSaveFileName( 0, "Adresslista (*.adr)");
		if (filename.isNull())
		{
			return;
		}
	}		      

	QFile f(filename);

	if ( !f.open( IO_WriteOnly ) )
		    return;
	      
	QTextStream t(&f);
	QString s;
	CContact* contact = CContact::getFirst();

	while ( contact != '\0')
	{
		t << contact->firstname() << "\n";
		t << contact->lastname() << "\n";
		t << contact->adress() << "\n";
		t << contact->phoneNumber() << "\n";
		contact=contact->getNext();
	}
	f.close();
}
/* 
 * public slot
 */
void MainWindow::slotAdd()
{
	ContactModifier add;
	if(add.exec() == QDialog::Accepted)
		updateView();
}
/* 
 * public slot
 */
void MainWindow::slotDel()
{
	QListViewItem* lvi = ContactView->selectedItem();

  if (lvi == '\0')
	{
		return;
	}
	
	int num = lvi->text(0).toInt();

	if (num < 1 || num > CContact::getNum())
		return;

	CContact* contact = CContact::getFirst();
	
	for (int i = 1; i < num; i++, contact = contact->getNext())
	{
		if (contact->getNext() == '\0')
		{
			return;
		}
	}

	delete contact;
	updateView();
	//qWarning( "MainWindow::slotDel() not yet implemented!" ); 
}
/* 
 * public slot
 */
void MainWindow::slotLoad()
{
	filename = QFileDialog::getOpenFileName(0, "Adressfiler (*.adr)", this); 

	QFile f(filename);
	if ( !f.open( IO_ReadOnly ) )
		return;
		    	
	while (CContact::getNum() != 0)
	{
		delete CContact::getFirst();
	}
	
	QTextStream t(&f);

	while (!t.eof())
	{
		QString fname = t.readLine();
		QString lname = t.readLine();
		QString adr		= t.readLine();
		QString pn		= t.readLine();
    if (fname == "" && lname == "" && lname == "" && pn == "")
			      continue;
		(void) new CContact(fname, lname, adr, pn);
	}
	updateView();
}
/* 
 * public slot
 */
void MainWindow::slotSearch()
{
    qWarning( "MainWindow::slotSearch() not yet implemented!" ); 
}

void MainWindow::slotModify(QListViewItem* lvi)
{
	if (lvi == '\0')
	{
		return;
	}
	
	int num = lvi->text(0).toInt();

	if (num < 1 || num > CContact::getNum())
		return;

	CContact* contact = CContact::getFirst();
	
	for (int i = 1; i < num; i++, contact = contact->getNext())
	{
		if (contact->getNext() == '\0')
		{
			return;
		}
	}
	ContactModifier modify(contact);
	if(modify.exec() == QDialog::Accepted)
		updateView();
}

void MainWindow::slotModify()
{
	QListViewItem* lvi = ContactView->selectedItem();

	if (lvi == '\0')
	{
		return;
	}
	
	int num = lvi->text(0).toInt();

	if (num < 1 || num > CContact::getNum())
		return;

	CContact* contact = CContact::getFirst();
	
	for (int i = 1; i < num; i++, contact = contact->getNext())
	{
		if (contact->getNext() == '\0')
		{
			return;
		}
	}
	ContactModifier modify(contact);
	if(modify.exec() == QDialog::Accepted)
		updateView();
}
/*
 * This funtion puts all contacts in the listview
 */
void MainWindow::updateView()
{
	
	ContactView->clear();

	CContact* contact = CContact::getFirst();

	int i = 1;
	char s[100];

	while (contact != '\0')
	{
		sprintf(s,"%i",i);//.arg(i);
		(void) new QListViewItem(ContactView, s, contact->lastname(), contact->firstname(), contact->adress(), contact->phoneNumber());
		contact = contact->getNext();
		i++;
	}
}
